==> pdapi-0.1.4-sources.jar: ml/pluto7073/pdapi/item/MilkBottleItem.java <==
package ml.pluto7073.pdapi.item;

import net.minecraft.class_1268;
import net.minecraft.class_1271;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_174;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1839;
import net.minecraft.class_1937;
import net.minecraft.class_3222;
import net.minecraft.class_3414;
import net.minecraft.class_3417;
import net.minecraft.class_3468;
import net.minecraft.class_4174;
import net.minecraft.class_5328;
import net.minecraft.item.*;

public class MilkBottleItem extends class_1792 {

    private static final class_4174 MilkFood = (new class_4174.class_4175()).method_19240().method_19238(1).method_19237(5).method_19242();

    public MilkBottleItem() {
        super(new class_1792.class_1793().method_7889(16).method_19265(MilkFood).method_7896(class_1802.field_8469));
    }

    public class_1799 method_7861(class_1799 stack, class_1937 world, class_1309 user) {
        super.method_7861(stack, world, user);
        if (user instanceof class_3222 serverPlayerEntity) {
            class_174.field_1198.method_8821(serverPlayerEntity, stack);
            serverPlayerEntity.method_7259(class_3468.field_15372.method_14956(this));
        }

        if (!world.field_9236) {
            user.method_6012();
        }

        if (stack.method_7960()) {
            return new class_1799(class_1802.field_8469);
        } else {
            if (user instanceof class_1657 playerEntity && !((class_1657)user).method_7337()) {
                class_1799 itemStack = new class_1799(class_1802.field_8469);
                if (!playerEntity.method_31548().method_7394(itemStack)) {
                    playerEntity.method_7328(itemStack, false);
                }
            }

            return stack;
        }
    }

    public class_1839 method_7853(class_1799 stack) {
        return class_1839.field_8946;
    }

    public class_3414 method_21831() {
        return class_3417.field_20613;
    }

    public class_3414 method_21830() {
        return class_3417.field_20613;
    }

    public class_1271<class_1799> method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        return class_5328.method_29282(world, user, hand);
    }

}

==> pdapi-1.20.1+0.3.10-sources.jar: ml/pluto7073/pdapi/item/MilkBottleItem.java <==
package ml.pluto7073.pdapi.item;

import net.minecraft.class_1268;
import net.minecraft.class_1271;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_174;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1839;
import net.minecraft.class_1937;
import net.minecraft.class_3222;
import net.minecraft.class_3414;
import net.minecraft.class_3417;
import net.minecraft.class_3468;
import net.minecraft.class_4174;
import net.minecraft.class_5328;
import net.minecraft.class_6328;

@class_6328
public class MilkBottleItem extends class_1792 {

    private static final class_4174 MilkFood = (new class_4174.class_4175()).method_19240().method_19238(1).method_19237(5).method_19242();

    public MilkBottleItem() {
        super(new class_1792.class_1793().method_7889(16).method_19265(MilkFood).method_7896(class_1802.field_8469));
    }

    public class_1799 method_7861(class_1799 stack, class_1937 world, class_1309 user) {
        super.method_7861(stack, world, user);
        if (user instanceof class_3222 serverPlayerEntity) {
            class_174.field_1198.method_8821(serverPlayerEntity, stack);
            serverPlayerEntity.method_7259(class_3468.field_15372.method_14956(this));
        }

        if (!world.field_9236) {
            user.method_6012();
        }

        if (stack.method_7960()) {
            return new class_1799(class_1802.field_8469);
        } else {
            if (user instanceof class_1657 playerEntity && !((class_1657)user).method_7337()) {
                class_1799 itemStack = new class_1799(class_1802.field_8469);
                if (!playerEntity.method_31548().method_7394(itemStack)) {
                    playerEntity.method_7328(itemStack, false);
                }
            }

            return stack;
        }
    }

    public class_1839 method_7853(class_1799 stack) {
        return class_1839.field_8946;
    }

    public class_3414 method_21831() {
        return class_3417.field_20613;
    }

    public class_3414 method_21830() {
        return class_3417.field_20613;
    }

    public class_1271<class_1799> method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        return class_5328.method_29282(world, user, hand);
    }

}
